@@ -103,7 +103,7 @@ class Fs_cdr_config_class extends Safe_configurable_object_class
         $this->add_field('http/log-http-and-disk', 'log-http-and-disk', 'hidden', 'true');
         $this->add_field('http/auth-scheme', 'auth-scheme', 'hidden', 'any');
         // common stuff (hidden)
-        $this->add_field('common/log-b-leg', 'log-b-leg', 'hidden', 'false');
+        $this->add_field('common/log-b-leg', 'log-b-leg', 'hidden', 'true');
         $this->add_field('common/prefix-a-leg', 'prefix-a-leg', 'hidden', 'false');
         
         return parent::configure();
@@ -132,6 +132,7 @@ class Fs_cdr_config_class extends Safe_configurable_object_class
 }
 class Fs_cdr_module_class extends Fs_module_class
 {
+    private $_mod_name = "mod_xml_cdr";
     /**
      * @brief
      *           
@@ -177,7 +178,7 @@ class Fs_cdr_module_class extends Fs_module_class
      */
     public function get_fs_module_name()
     {
-        return 'mod_xml_' . $this->name() . '.so';
+        return $this->_mod_name . '.so';
     }
     /**
      * @brief
@@ -197,6 +198,11 @@ class Fs_cdr_module_class extends Fs_module_class
             unset($cfg['local']);
         }else{
             $cfg['local']['rotate'] = 'true';
+            // Extract cron related data
+            $cleanup['schedule'] = $cfg['local']['schedule'];
+            $cleanup['max_size'] = $cfg['local']['max_size'];
+            unset($cfg['local']['schedule']);
+            unset($cfg['local']['max_size']);
         }
         if ('true' != $cfg['global']['http']) {
             // Remove http parameters
@@ -212,6 +218,7 @@ class Fs_cdr_module_class extends Fs_module_class
         $xml_writer->startElement('configuration');
         $xml_writer->writeAttribute('name', 'xml_cdr.conf');
         $xml_writer->writeAttribute('description', 'XML CDR CURL logger');
+
         // Add all parameters
         $xml_writer->startElement('settings');
         foreach ($cfg as $category => $cat_cfg) {
@@ -219,7 +226,7 @@ class Fs_cdr_module_class extends Fs_module_class
                 $xml_writer->startElement('param');
                 $xml_writer->writeAttribute('name', $k);
                 $xml_writer->writeAttribute('value', $v);
-                $xml_writer->fullEndElement();
+                $xml_writer->endElement();
             }
         }
         // Close settings
@@ -238,17 +245,17 @@ class Fs_cdr_module_class extends Fs_module_class
         $config_manager->add_config(new Safe_configuration_class('/etc/cron.monthly/'.$file_name, '', Safe_configuration_class::CFG_DELETE, Safe_configuration_class::CFG_FILE));
         
         //creates a file named sng-cdr-cleanup will be created in /etc/cron.<local/schedule> directory 
-        if('true' == $cfg['local']['rotate']){
+        if($cleanup){
             $file_content = '#!/bin/bash'.PHP_EOL.
             'nice -n 20 /usr/local/nsc/bin/python /usr/local/sng/scripts/sng-cdr-rotator --path /usr/local/nsc/log/xml_cdr --size '.
-            $cfg['local']['max_size'].PHP_EOL;
+            $cleanup['max_size'].PHP_EOL;
             //create file 
-            $config_manager->add_config(new Safe_configuration_class('/etc/cron.'.$cfg['local']['schedule'].'/'.$file_name, $file_content, Safe_configuration_class::CFG_UPDATE, Safe_configuration_class::CFG_FILE));
+            $config_manager->add_config(new Safe_configuration_class('/etc/cron.'.$cleanup['schedule'].'/'.$file_name, $file_content, Safe_configuration_class::CFG_UPDATE, Safe_configuration_class::CFG_FILE));
             //chmod add executable to file
-            $config_manager->add_config(new Safe_configuration_class('/etc/cron.'.$cfg['local']['schedule'].'/'.$file_name, ' +x ', Safe_configuration_class::CFG_UPDATE, Safe_configuration_class::CFG_CHMOD));
+            $config_manager->add_config(new Safe_configuration_class('/etc/cron.'.$cleanup['schedule'].'/'.$file_name, ' +x ', Safe_configuration_class::CFG_UPDATE, Safe_configuration_class::CFG_CHMOD));
             //File owner should be changed to root
-            $config_manager->add_config(new Safe_configuration_class('/etc/cron.'.$cfg['local']['schedule'].'/'.$file_name, ' root ', Safe_configuration_class::CFG_UPDATE, Safe_configuration_class::CFG_CHOWN));
-            $config_manager->add_config(new Safe_configuration_class('/etc/cron.'.$cfg['local']['schedule'].'/', ' root ', Safe_configuration_class::CFG_UPDATE, Safe_configuration_class::CFG_CHOWN));
+            $config_manager->add_config(new Safe_configuration_class('/etc/cron.'.$cleanup['schedule'].'/'.$file_name, ' root ', Safe_configuration_class::CFG_UPDATE, Safe_configuration_class::CFG_CHOWN));
+            $config_manager->add_config(new Safe_configuration_class('/etc/cron.'.$cleanup['schedule'].'/', ' root ', Safe_configuration_class::CFG_UPDATE, Safe_configuration_class::CFG_CHOWN));
         }
         
         return parent::generate_config($config_manager);
@@ -261,6 +268,9 @@ class Fs_cdr_module_class extends Fs_module_class
                 'description' => 'Call Data Records',
                 'filesystem' => true,
                 'pattern' => $cfg_manager->directory('log') . '/xml_cdr/*.xml',
+                'file_ext' => 'cdr.xml',
+                'file_dir' => $cfg_manager->directory('log') . '/xml_cdr',
+                'recursive' => true,
                 'global_capabilities' => array(
                     'download',
                     'delete'
@@ -282,11 +292,52 @@ class Fs_cdr_module_class extends Fs_module_class
         preg_match($regex_pattern, $base, $match);
         return $match['key'];
     }
-    function get_data_file_content_by_key($data_name, $key)
+    /**
+     * @brief Invoked after a successfull write_config
+     *         
+     * @return
+     */
+    public function post_write_config()
     {
-        $cfg_manager = $this->node()->configuration_manager();
-        $content = file_get_contents($cfg_manager->directory('log') . '/xml_cdr/' . $key . '.cdr.xml');
-        return $content;
+        // Reload configuration
+        if (Safe_service_class::STATUS_RUNNING == $this->fs_app()->status()){
+            if($this->is_enabled()){
+                $rc = $this->eslapi_execute("reload ".$this->_mod_name, '', $output);
+            }else{
+                $rc = $this->eslapi_execute("unload ".$this->_mod_name, '', $output);
+            }
+        }
+        return parent::post_write_config();
+    }
+    public function support_reload(&$cfg_modified = null)
+    {
+        parent::support_reload($cfg_modified);
+        return true;
+    }
+    /**
+     * @brief Create config jobs for dialplan module
+     *           
+     * @param[in out] $config_manager
+     *           
+     * @return
+     */
+    public function reload_generate_config(&$config_manager, $obj_type=null)
+    {
+        if(!$this->generate_config($config_manager)) return false;
+        return parent::reload_generate_config($config_manager, $obj_type);
+    }
+
+    /**
+     * @brief 
+     *
+     * @param[in out] $obj_type
+     *
+     * @return 
+     */
+    public function reload_clear_modified($obj_type=null)
+    {
+        // the hard way :)
+        Safe_object_serializer_class::get_serializer()->clear_modified($this->_obj_base_path, true);
     }
 }
 /* End of file fs_application_class.php */
