@@ -1041,7 +1041,7 @@ class Fs_sip_module_class extends Fs_module_class
         $data['data']['prefix'] = $prefix;
         $data['data']['id'] = $sip_trunk->id();
         $sip = $sip_trunk->get_data_values(false);
-        if (!$carrier_name || "none" != $carrier_name) {
+        if ($carrier_name && "none" != $carrier_name) {
             $data['data']['enabled'] = 1;
             $carrier_profiles = $this->fs_app()->carrier_profiles();
             $carrier = $carrier_profiles[$carrier_name];
