@@ -393,6 +393,31 @@ EOD;
         }
     }
 }
+/**
+ * create a file cvs file
+ *
+ * @param $filename string
+ * @param $data     array
+ * @param $setting  array (csv format setting)
+ * @return boolean
+ */
+function safe_csv_download($obj_name = '', $data = null)
+{
+    $tmp_path = '/tmp/download-files/';
+    if(false == safe_verify_tmp($tmp_path)){
+        header("HTTP/1.0 403 Forbidden");
+        exit();
+    }else{
+        $name = php_uname('n') . '-' . $obj_name . '-' . date('Y-m-d-H-i-s') . '.csv';
+        $fp = fopen($tmp_path.$name, 'w');
+        foreach ($data as $obj_item){
+            fputcsv($fp, $obj_item);
+        }
+        fclose($fp);
+        safe_download($tmp_path.$name,null,$name,'text/csv',true);
+        $rs = unlink($tmp_path.$name);
+    }
+}
 /**
  * Download a file
  *
@@ -402,7 +427,7 @@ EOD;
  * @param $maxsize  int|string
  * @return boolean  
  */
-function safe_download($filename = '', $buffer = NULL, $user_filename = NULL, $mime = NULL)
+function safe_download($filename = '', $buffer = NULL, $user_filename = NULL, $mime = NULL, $delete = false)
 {
     // TODO: webconfig (the apache server is running under UID 101 so php also
     // $ph = popen("/usr/bin/sudo /bin/cat " . escapeshellarg($filename), "r");
@@ -456,7 +481,13 @@ function safe_download($filename = '', $buffer = NULL, $user_filename = NULL, $m
         header('Pragma: no-cache');
         header("Content-Length: " . strlen($data));
     }
-    exit($data);
+    if($delete === true){
+        echo($data);
+        @unlink($filename);
+        exit();
+    }else{
+        exit($data);
+    }
 }
 /**
  * Make a upload (AJAX style).
@@ -621,7 +652,10 @@ function safe_exec($command, $line_options = '', $arguments = '', &$return_var =
  */
 function safe_verify_tmp($path = '/tmp/SAFeUPLOADs')
 {
-    $path = realpath($path);
+    $tmp_path = realpath($path);
+    if($tmp_path !== false){
+        $path = $tmp_path;
+    }
     $path = preg_replace('#/+$#', '', $path); // remove trailing /
     $path = preg_replace('#/+#', '/', $path); // replace non-single /
     if (!is_dir($path)) {
