@@ -498,21 +498,20 @@ class Safe_application_class extends Safe_service_class
                             $output['restart_failed'] = 'System Apply Configuration and Restart Failed';
                             $rc = false;
                         }
-                    }else{
-                        // Check if some service with modified config and 
-                        // supporting reload and running -> post_write
-                        foreach($reload_list as $module_name => $module_obj_list) {
-                            $module = $this->find_module_by_name($module_name);
-                            // TODO - need to loop around obj_type
-                            if(is_subclass_of($module, "Safe_service_class")
-                                &&
-                                $module->status == Safe_service_class::STATUS_RUNNING ) {
-                                if(!$module->post_write_config()) {
-                                    $output[] = 'Post Write Failed for '.$module->name() . '.';
-                                }
+                    }
+                    // Check if some service with modified config and 
+                    // supporting reload and running -> post_write
+                    foreach($reload_list as $module_name => $module_obj_list) {
+                        $module = $this->find_module_by_name($module_name);
+                        // TODO - need to loop around obj_type
+                        if(is_subclass_of($module, "Safe_service_class")
+                            &&
+                            $module->status == Safe_service_class::STATUS_RUNNING ) {
+                            if(!$module->post_write_config()) {
+                                $output[] = 'Post Write Failed for '.$module->name() . '.';
                             }
                         }
-                    } 
+                    }
                 }
                 Safe_leave_critical_section();
             }
