@@ -28,8 +28,8 @@ class Sng_archive_data extends Sng_data_manager
     {
         parent::__construct();
     }
-    public function index()
+    public function index($module_name, $data_name, $offset = NULL)
     {
-        return $this->manage('nsc','archive');
+        return $this->manage('application','archive', $offset);
     }
-}
\ No newline at end of file
+}
