@@ -200,11 +200,15 @@ class Sng_data_manager extends Safe_CI_Controller
             $this->load->library('pagination');
             $pagination_config['base_url'] = '/SAFe/' . $this->router->fetch_class() . '/' . $this->router->fetch_method() . '/' . $module_name . '/' . $data_name;
             $pagination_config['total_rows'] = count($data_files);
-            $pagination_config['uri_segment'] = 6;
+            $pieces = explode("/", $_SERVER['REQUEST_URI']);
+            $pagination_config['uri_segment'] = 5;
+            if(count($pieces) > 7 ){
+                $pagination_config['uri_segment'] = count($pieces) - 2;
+            }
             $pagination_config['per_page'] = $max_per_page;
             $this->pagination->initialize($pagination_config);
             // Adjust data_files array
-            $data_files = array_slice($data_files, $array_offset, $max_per_page);
+            $data_files = array_slice($data_files, $array_offset, $max_per_page, true );
         }
         
         if($data_cfg['singleton'] && 0 != count($data_files)){
@@ -391,7 +395,7 @@ class Sng_data_manager extends Safe_CI_Controller
         $data['height'] = "600px";
         $data['min_height'] = "0px";
         $data['url_back'] = $_SERVER['HTTP_REFERER'];
-        $data['editor_data'] = $module->get_data_file_content_by_key($data_name, $data_key, NULL, 4096);
+        $data['editor_data'] = $module->get_data_file_content_by_key($data_name, $data_key, NULL);
         if (empty($data['editor_data'])) {
             $data['notif_error'][] = $data_cfg['description'] . ' ' . $data_key . ' not found.<br/>' . safe_button_click('cancel', 'Back', $data['url_back']);
         }
